/*

    ThermostatQA - test framework for Thermostat Monitoring Tool

    Copyright 2013 Red Hat, Inc.

This file is part of ThermostatQA

ThermostatQA is distributed under the GNU General Public License,
version 2 or any later version (with a special exception described
below, commonly known as the "Classpath Exception").

A copy of GNU General Public License (GPL) is included in this
distribution, in the file COPYING.

Linking ThermostatQA code with other modules is making a combined work
based on ThermostatQA.  Thus, the terms and conditions of the GPL
cover the whole combination.

As a special exception, the copyright holders of ThermostatQA give you
permission to link this code with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on ThermostatQA code.  If you modify ThermostatQA, you may
extend this exception to your version of the software, but you are
not obligated to do so.  If you do not wish to do so, delete this
exception statement from your version.
*/

package org.thermostat.qa.framework;

public class Assert
{
    /**
     * Assertion if two objects are equal.
     * 
     * @param o1
     *            first object
     * @param o2
     *            second object
     * @param message
     *            message printed when assertion has failed
     * @throws AssertionError
     *             thrown to indicate that an assertion has failed
     */
    public static void assertEquals(Object o1, Object o2, String message)
            throws AssertionError
    {
        assertTrue(o1.equals(o2), message);
    }

    /**
     * Assertion if two characters are equal.
     * 
     * @param value1
     *            first value to be compared
     * @param value2
     *            second value to be compared
     * @param message
     *            message printed when assertion has failed
     * @throws AssertionError
     *             thrown to indicate that an assertion has failed
     */
    public static void assertEquals(char value1, char value2, String message)
            throws AssertionError
    {
        assertTrue(value1 == value2, message);
    }

    /**
     * Assertion if two bytes are equal.
     * 
     * @param value1
     *            first value to be compared
     * @param value2
     *            second value to be compared
     * @param message
     *            message printed when assertion has failed
     * @throws AssertionError
     *             thrown to indicate that an assertion has failed
     */
    public static void assertEquals(byte value1, byte value2, String message)
            throws AssertionError
    {
        assertTrue(value1 == value2, message);
    }

    /**
     * Assertion if two shorts are equal.
     * 
     * @param value1
     *            first value to be compared
     * @param value2
     *            second value to be compared
     * @param message
     *            message printed when assertion has failed
     * @throws AssertionError
     *             thrown to indicate that an assertion has failed
     */
    public static void assertEquals(short value1, short value2,
            String message) throws AssertionError
    {
        assertTrue(value1 == value2, message);
    }

    /**
     * Assertion if two integers are equal.
     * 
     * @param value1
     *            first value to be compared
     * @param value2
     *            second value to be compared
     * @param message
     *            message printed when assertion has failed
     * @throws AssertionError
     *             thrown to indicate that an assertion has failed
     */
    public static void assertEquals(int value1, int value2, String message)
            throws AssertionError
    {
        assertTrue(value1 == value2, message);
    }

    /**
     * Assertion if two longs are equal.
     * 
     * @param value1
     *            first value to be compared
     * @param value2
     *            second value to be compared
     * @param message
     *            message printed when assertion has failed
     * @throws AssertionError
     *             thrown to indicate that an assertion has failed
     */
    public static void assertEquals(long value1, long value2, String message)
            throws AssertionError
    {
        assertTrue(value1 == value2, message);
    }

    /**
     * Assertion if two floats are equal.
     * 
     * @param value1
     *            first value to be compared
     * @param value2
     *            second value to be compared
     * @param message
     *            message printed when assertion has failed
     * @throws AssertionError
     *             thrown to indicate that an assertion has failed
     */
    public static void assertEquals(float value1, float value2,
            String message) throws AssertionError
    {
        assertTrue(value1 == value2, message);
    }

    /**
     * Assertion if two doubles are equal.
     * 
     * @param value1
     *            first value to be compared
     * @param value2
     *            second value to be compared
     * @param message
     *            message printed when assertion has failed
     * @throws AssertionError
     *             thrown to indicate that an assertion has failed
     */
    public static void assertEquals(double value1, double value2,
            String message) throws AssertionError
    {
        assertTrue(value1 == value2, message);
    }

    /**
     * Assertion for true condition.
     * 
     * @param bool
     *            boolean value to be tested
     * @param message
     *            message printed when assertion has failed
     * @throws AssertionError
     *             thrown to indicate that an assertion has failed
     */
    public static void assertTrue(boolean bool, String message)
            throws AssertionError
    {
        if (!bool)
        {
            throw new AssertionError(message);
        }
    }

    /**
     * Assertion for true condition.
     * 
     * @param bool
     *            boolean value to be tested
     * @param message
     *            message printed when assertion has failed
     * @throws AssertionError
     *             thrown to indicate that an assertion has failed
     */
    public static void assertTrue(Boolean bool, String message)
            throws AssertionError
    {
        if (!bool.booleanValue())
        {
            throw new AssertionError(message);
        }
    }

    /**
     * Assertion for false condition.
     * 
     * @param bool
     *            boolean value to be tested
     * @param message
     *            message printed when assertion has failed
     * @throws AssertionError
     *             thrown to indicate that an assertion has failed
     */
    public static void assertFalse(boolean bool, String message)
            throws AssertionError
    {
        if (bool)
        {
            throw new AssertionError(message);
        }
    }

    /**
     * Assertion for false condition.
     * 
     * @param bool
     *            boolean value to be tested
     * @param message
     *            message printed when assertion has failed
     * @throws AssertionError
     *             thrown to indicate that an assertion has failed
     */
    public static void assertFalse(Boolean bool, String message)
            throws AssertionError
    {
        if (bool.booleanValue())
        {
            throw new AssertionError(message);
        }
    }

    /**
     * Assertion if given reference is null.
     * 
     * @param object
     *            reference to be tested
     * @param message
     *            message printed when assertion has failed
     * @throws AssertionError
     *             thrown to indicate that an assertion has failed
     */
    public static void assertNull(Object object, String message)
            throws AssertionError
    {
        assertTrue(object == null, message);
    }

    /**
     * Assertion if given reference is not null.
     * 
     * @param object
     *            reference to be tested
     * @param message
     *            message printed when assertion has failed
     * @throws AssertionError
     *             thrown to indicate that an assertion has failed
     */
    public static void assertNotNull(Object object, String message)
            throws AssertionError
    {
        assertTrue(object != null, message);
    }

    /**
     * Assertion if given string is empty.
     * 
     * @param string
     *            string to be tested.
     * @param message
     *            message printed when assertion has failed
     * @throws AssertionError
     *             thrown to indicate that an assertion has failed
     */
    public static void assertEmpty(String str, String message)
            throws AssertionError
    {
        assertTrue(str.isEmpty(), message);
    }

    /**
     * Assertion if given string is not empty.
     * 
     * @param string
     *            string to be tested.
     * @param message
     *            message printed when assertion has failed
     * @throws AssertionError
     *             thrown to indicate that an assertion has failed
     */
    public static void assertNotEmpty(String str, String message)
            throws AssertionError
    {
        assertFalse(str.isEmpty(), message);
    }

    /**
     * Assertion if object is an instance of a given class.
     * 
     * @param object
     *            object reference to be tested
     * @param clazz
     *            class
     * @param message
     *            message printed when assertion has failed
     * @throws AssertionError
     *             thrown to indicate that an assertion has failed
     */
    public static void assertType(Object object, Class<?> clazz,
            String message) throws AssertionError
    {
        assertTrue(object.getClass().equals(clazz), message);
    }

}
